@@ -13,7 +13,6 @@ SAMPLE_PLUGIN_NAME = "my-plugin"
 
 @pytest.fixture
 def pm(sample_path):
-
     pm = PluginManager()
     pm.discover()
     assert len(pm._manifests) == 0
@@ -164,7 +163,6 @@ def _assert_sample_enabled(plugin_manager: PluginManager, enabled=True):
 
 
 def test_enable_disable(uses_sample_plugin, plugin_manager: PluginManager, tmp_path):
-
     _assert_sample_enabled(plugin_manager)
     # just to test the enabled= kwarg on iter_manifests
     # (this would show *only* disabled plugins)
@@ -224,3 +222,17 @@ def test_plugin_context_dispose():
     pm.get_context("test").register_disposable(mock)
     pm.deactivate("test")
     mock.assert_called_once()
+
+
+def test_plugin_context_dispose_error(caplog):
+    """Test errors when executing dispose functions caught correctly."""
+    pm = PluginManager()
+    mf = PluginManifest(name="test")
+    pm.register(mf)
+
+    def dummy_error():
+        raise ValueError("This is an error")
+
+    pm.get_context("test").register_disposable(dummy_error)
+    pm.deactivate("test")
+    assert caplog.records[0].msg == "Error while disposing test; This is an error"
